@@ -726,6 +726,14 @@ static gboolean end_time_check (gtk_video_private_t *priv)
   return FALSE;
 }
 
+static gboolean frame_priv_cb (gtk_video_private_t *priv)
+{
+  priv->frame_cb_id = 0;
+  if (priv->frame_cb)
+    priv->frame_cb (priv->frame_cb_data);
+  return FALSE;
+}
+
 static void frame_output_cb (void *gv_gen,
 			     int video_width, int video_height,
 			     double video_pixel_aspect,
@@ -796,12 +804,8 @@ static void frame_output_cb (void *gv_gen,
    if (priv->end_time && !priv->end_time_id)
      priv->end_time_id = g_idle_add ((GSourceFunc) end_time_check, priv);
 
-  if (priv->frame_cb)
-  {
-    if (priv->frame_cb_id)
-      g_source_remove (priv->frame_cb_id);
-    priv->frame_cb_id = g_idle_add ((GSourceFunc) priv->frame_cb, priv->frame_cb_data);
-  }
+  if (priv->frame_cb && !priv->frame_cb_id)
+    priv->frame_cb_id = g_idle_add ((GSourceFunc) frame_priv_cb, priv);
 }
 
 #ifdef HAVE_XCB
@@ -1863,10 +1867,11 @@ gtk_video_deny_shrink (GtkVideo *gtv)
 static gboolean
 gtv_allow_shrink (gpointer gtv)
 {
+  ((GtkVideo *)gtv)->priv->minimising = 0;
+
   if (is_fullscreen (((GtkVideo *)gtv)->priv))
     return FALSE;
 
-  ((GtkVideo *)gtv)->priv->minimising = 0;
   ((GtkVideo *)gtv)->widget.requisition =
     (GtkRequisition){ GTK_VIDEO_MIN_WIDTH, GTK_VIDEO_MIN_HEIGHT };
   g_object_set (gtv, "width-request", -1, "height-request", -1, NULL);
