@@ -1336,7 +1336,7 @@ static JSBool js_event (JSContext *cx, uintN argc, jsval *vp)
 
 static JSBool js_vdr (JSContext *cx, uintN argc, jsval *vp)
 {
-  const char *const prefixes[] = { "vdr:/", "netvdr:/", NULL };
+  const char *const prefixes[] = { "vdr:/", "netvdr:/", "xvdr:/", NULL };
   return js_event_generic (cx, argc, vp, "vdr", prefixes,
 			   &xine_vdr, NULL);
 }
