@@ -69,6 +69,7 @@ static GtkTreeSelection *sel;
 static GtkToggleButton *repeat_button, *random_button, *repeat_track_button;
 static char            logo_mrl[1024];
 static int             logo_mode;
+static gint            browse_cb = 0;
 
 static struct {
   GtkDialog *dbox;
@@ -175,6 +176,12 @@ static gboolean playlist_browse_set (const play_item_t *item)
   return FALSE;
 }
 
+static gboolean playlist_browse_set_cb (const play_item_t *item)
+{
+  browse_cb = 0;
+  return playlist_browse_set (item);
+}
+
 static gboolean map_cb (GtkWidget* widget, gpointer data)
 {
   gdk_window_set_events (widget->window,
@@ -2312,7 +2319,6 @@ void playlist_play_from (int list_pos, int pos, int pos_time)
   GtkTreePath *path;
   char         indices[10];
   play_item_t *play_item;
-  static gint  browse_cb = 0;
 
   logo_mode = 0;
 
@@ -2334,7 +2340,7 @@ void playlist_play_from (int list_pos, int pos, int pos_time)
 
   if (browse_cb)
     g_source_remove (browse_cb);
-  browse_cb = g_timeout_add (1000, (GSourceFunc)playlist_browse_set, play_item);
+  browse_cb = g_timeout_add (1000, (GSourceFunc)playlist_browse_set_cb, play_item);
 
   snprintf (indices, sizeof (indices), "%d", list_pos);
   path = gtk_tree_path_new_from_string (indices);
